rbac

package
v0.0.0-...-b25413d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 22, 2025 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Load

func Load(ctx context.Context, db *sql.DB, dialect ormdriver.Dialect, prefix string, e *casbin.Enforcer) error

Load fills the Casbin enforcer with policies and groupings from the database.

func ReloadEnforcer

func ReloadEnforcer(ctx context.Context, db *sql.DB)

ReloadEnforcer is a hook for reloading the Casbin enforcer after RBAC changes. Currently it is a no-op and can be overridden elsewhere.

Types

This section is empty.

Jump to